@@ -3,7 +3,7 @@ package rtnl
 import (
 	"net"
 
-	"github.com/jsimonetti/rtnetlink"
+	"github.com/jsimonetti/rtnetlink/v2"
 )
 
 // Neigh represents a neighbour table entry (e.g. an entry in the ARP table)
@@ -11,6 +11,10 @@ type Neigh struct {
 	HwAddr    net.HardwareAddr // Link-layer address
 	IP        net.IP           // Network-layer address
 	Interface *net.Interface   // Network interface
+
+	// Bitfield representing the state of the neighbor entry,
+	// corresponding to the NUD_ constants.
+	State uint16
 }
 
 // Neighbours lists entries from the neighbor table (e.g. the ARP table).
@@ -38,7 +42,9 @@ func (c *Conn) Neighbours(ifc *net.Interface, family int) (r []*Neigh, err error
 		if !ok {
 			iface, err = c.LinkByIndex(ifindex)
 			if err != nil {
-				return nil, err
+				// Received a neigh entry for a link that no longer exists, so we cannot
+				// populate the Interface field. Skip the entry.
+				continue
 			}
 			ifcache[ifindex] = iface
 		}
@@ -46,6 +52,7 @@ func (c *Conn) Neighbours(ifc *net.Interface, family int) (r []*Neigh, err error
 			HwAddr:    m.Attributes.LLAddress,
 			IP:        m.Attributes.Address,
 			Interface: iface,
+			State:     m.State,
 		}
 		r = append(r, p)
 	}
